==> infra-4.4.2-sources.jar: com/liveperson/infra/utils/TlsUtil.java <==
package com.liveperson.infra.utils;

import android.os.Build;

import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.network.Tls12SocketFactory;

import java.util.ArrayList;
import java.util.List;

import javax.net.ssl.SSLContext;

import okhttp3.ConnectionSpec;
import okhttp3.OkHttpClient;
import okhttp3.TlsVersion;

/**
 * Remove this class once minSdkVersion is higher than KitKat.
 * Created by Yanda on 2019/03/08
 */
public class TlsUtil {

    private static final String TAG = "TlsUtil";
    private static final String TLS_1_2 = "TLSv1.2";

    /**
     * Enable TLSv1.2 for KitKat.
     *
     * @param client
     */
    public static void enableTls12ForKitKat(OkHttpClient.Builder client) {
        if (Build.VERSION.SDK_INT == Build.VERSION_CODES.KITKAT) {
            try {
                SSLContext sc = SSLContext.getInstance(TLS_1_2);
                sc.init(null, null, null);
                //noinspection deprecation Didn't find out a new method to use here.
                client.sslSocketFactory(new Tls12SocketFactory(sc.getSocketFactory()));

                ConnectionSpec cs = new ConnectionSpec.Builder(ConnectionSpec.MODERN_TLS)
                        .tlsVersions(TlsVersion.TLS_1_2)
                        .build();

                List<ConnectionSpec> specs = new ArrayList<>();
                specs.add(cs);
                specs.add(ConnectionSpec.COMPATIBLE_TLS);
                specs.add(ConnectionSpec.CLEARTEXT);
                client.connectionSpecs(specs);
            } catch (Exception e) {
                LPLog.INSTANCE.e(TAG, "Error while setting TLS 1.2", e);
            }
        }
    }
}

==> infra-4.7.1-sources.jar: com/liveperson/infra/utils/TlsUtil.java <==
package com.liveperson.infra.utils;

import android.os.Build;

import com.liveperson.infra.log.LPLog;
import com.liveperson.infra.network.Tls12SocketFactory;

import java.util.ArrayList;
import java.util.List;

import javax.net.ssl.SSLContext;

import okhttp3.ConnectionSpec;
import okhttp3.OkHttpClient;
import okhttp3.TlsVersion;

import static com.liveperson.infra.errors.ErrorCode.ERR_0000002B;

/**
 * Remove this class once minSdkVersion is higher than KitKat.
 * Created by Yanda on 2019/03/08
 */
public class TlsUtil {

    private static final String TAG = "TlsUtil";
    private static final String TLS_1_2 = "TLSv1.2";

    /**
     * Enable TLSv1.2 for KitKat.
     *
     * @param client
     */
    public static void enableTls12ForKitKat(OkHttpClient.Builder client) {
        if (Build.VERSION.SDK_INT == Build.VERSION_CODES.KITKAT) {
            try {
                SSLContext sc = SSLContext.getInstance(TLS_1_2);
                sc.init(null, null, null);
                //noinspection deprecation Didn't find out a new method to use here.
                client.sslSocketFactory(new Tls12SocketFactory(sc.getSocketFactory()));

                ConnectionSpec cs = new ConnectionSpec.Builder(ConnectionSpec.MODERN_TLS)
                        .tlsVersions(TlsVersion.TLS_1_2)
                        .build();

                List<ConnectionSpec> specs = new ArrayList<>();
                specs.add(cs);
                specs.add(ConnectionSpec.COMPATIBLE_TLS);
                specs.add(ConnectionSpec.CLEARTEXT);
                client.connectionSpecs(specs);
            } catch (Exception e) {
                LPLog.INSTANCE.e(TAG, ERR_0000002B, "Error while setting TLS 1.2", e);
            }
        }
    }
}
